@@ -5,13 +5,18 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 import aws_cdk.core._jsii
 import constructs._jsii
 
-__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-kinesisanalytics", "1.46.0", __name__[0:-6], "aws-kinesisanalytics@1.46.0.jsii.tgz")
+__jsii_assembly__ = jsii.JSIIAssembly.load(
+    "@aws-cdk/aws-kinesisanalytics",
+    "1.165.0",
+    __name__[0:-6],
+    "aws-kinesisanalytics@1.165.0.jsii.tgz",
+)
 
 __all__ = [
     "__jsii_assembly__",
